@@ -1,6 +1,9 @@
 package
   My::Dist;
 
+use strict;
+use warnings;
+
 # ABSTRACT: This is my Dist
 # VERSION
 
