@@ -5,8 +5,8 @@ use warnings;
 use Dist::Zilla::App -command;
 use Ref::Util qw( is_hashref );
 
-# ABSTRACT: Print your alien distributions alien prerequisites
-our $VERSION = '0.02'; # VERSION
+# ABSTRACT: (DEPRECATED) Print your alien distributions alien prerequisites
+our $VERSION = '0.03'; # VERSION
 
 
 sub abstract { "print your alien distributions alien prerequisites" }
@@ -65,11 +65,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::App::Command::aliendeps - Print your alien distributions alien prerequisites
+Dist::Zilla::App::Command::aliendeps - (DEPRECATED) Print your alien distributions alien prerequisites
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -77,6 +77,10 @@ version 0.02
 
 =head1 DESCRIPTION
 
+B<NOTE>: This L<Dist::Zilla> subcommand is deprecated in favor of L<App::af>
+which can produce useful results with L<alienfile> + L<Alien::Build> with the
+C<af missing> command.
+
 L<Alien::Base> based L<Alien> distributions may have optional dependencies
 that are required when it is determined that a build from source code is
 necessary.  This command probes your distribution for such optional requirements
